function Fern(N)

% This routine draws a fern (like Barnsley's).
%
% The transformations for the fern are each in the form
% T(x,y = (a*x+b*y+e, c*x+d*y+f). Each transformation is 
% executed iteratively with a certain probability.
%
% INPUT
%	N -> The number of iterations.

% Close all existing figure windows. Delete this line
% if you do not want this action.
close all

% Initialize figure window and axes
fig1=figure;
ax1=axes;

% Initialize some space to hold the sequence of points
% X1, X2, ..., XN
X=zeros(N,2);

% The initial value X1 = [0.5,0.5].
X(1,:)=[0.5,0.5];   % X(1,:) means "first row, every column."

% The main loop where the iterations are performed.
for k=1:N-1
	r=rand;
	if r<.25
		X(k+1,:)=T(X(k,:),0,0.2439,0,0.3053,0,0);
	elseif r<.5
		X(k+1,:)=T(X(k,:),0.7248,0.0337,-0.0253,0.7426,0.206,0.2538);
	elseif r<.75
		X(k+1,:)=T(X(k,:),0.1583,-0.1297,0.355,0.3676,0.1383,0.175);
	else
		X(k+1,:)=T(X(k,:),0.3386,0.3694,0.2227,-0.0756,0.0679,0.0826);
	end
end

plot(X(:,1),X(:,2),'.','Color',[0,.5,0],'markersize',1)	
whitebg('white')

axis off

function U=T(X,a,b,c,d,e,f)
U=zeros(1,2);
U(1)=a*X(1)+b*X(2)+e;
U(2)=c*X(1)+d*X(2)+f;
