function Maple(N)

% This routine draws a maple leaf. 
%
% The transformations for the leaf are each in the form
% T(x,y) = (a*x+b*y+e, c*x+d*y+f). Each transformation is 
% executed iteratively with a certain probability.
%
% INPUT
%	N -> The number of iterations.
%
% Close all existing figure windows. Delete this line
% if you do not want this action.
close all

% Initialize figure window and axes
fig1=figure;
ax1=axes;

% Initialize some space to hold the sequence of points
% X1, X2, ..., XN
X=zeros(N,2);

% The initial value X1 = [0.5,0.5].
X(1,:)=[0.5,0.5];   % X(1,:) means "first row, every column."

% The main loop where the iterations are performed.
for k=1:N-1
	r=rand;
	if r<.25
		X(k+1,:)=T(X(k,:),0.14,0.01,0,0.51,-0.08,-1.31);
	elseif r<.5
		X(k+1,:)=T(X(k,:),0.43,0.52,-0.45,0.5,1.49,-0.75);
	elseif r<.75
		X(k+1,:)=T(X(k,:),0.45,-0.49,0.47,0.47,-1.62,-0.74);
	else
		X(k+1,:)=T(X(k,:),0.49,0,0,0.51,0.02,1.62);
	end
end

% To add some color, try scatter instead of plot:
% C=rand(N,3);
% C=[zeros(1,N);1/N:1/N:1;zeros(1,N)]';
% scatter(X(:,1),X(:,2),1,C)
plot(X(:,1),X(:,2),'x','Color',[0,.3,.1],'markersize',1)

axis off

function U=T(X,a,b,c,d,e,f)
U=zeros(1,2);
U(1)=a*X(1)+b*X(2)+e;
U(2)=c*X(1)+d*X(2)+f;
