function Spiral(N)

% This routine draws a spiral.
%
% The transformations for the spiral are each in the form
% T(x,y = (a*x+b*y+e, c*x+d*y+f). Each transformation is 
% executed iteratively with a certain probability.
%
% INPUT
%	N -> The number of iterations.

% Close all existing figure windows. Delete this line
% if you do not want this action.
close all

% Initialize figure window and axes
fig1=figure;
ax1=axes;

% Initialize some space to hold the sequence of points
% X1, X2, ..., XN
X=zeros(N,2);

% The initial value X1 = [0.5,0.5].
X(1,:)=[0.5,0.5];   % X(1,:) means "first row, every column."

% The main loop where the iterations are performed.
for k=1:N-1
	r=rand;
	if r<.9
		X(k+1,:)=T(X(k,:),0.787879,-0.424242,0.242424,0.859848,1.758647,1.408065);
	elseif r<.95
		X(k+1,:)=T(X(k,:),-0.121212,0.257576,0.151515,0.053030,-6.721654,1.377236);
	else
		X(k+1,:)=T(X(k,:),0.181818,-0.136364,0.090909,0.181818,6.086107,1.568035);
	end
end

plot(X(:,1),X(:,2),'.','Color',[1,0,0],'markersize',1)	

axis off

function U=T(X,a,b,c,d,e,f)
U=zeros(1,2);
U(1)=a*X(1)+b*X(2)+e;
U(2)=c*X(1)+d*X(2)+f;
